@@ -3,7 +3,7 @@
 package KiokuDB;
 use Moose;
 
-our $VERSION = "0.46";
+our $VERSION = "0.47";
 
 use constant SERIAL_IDS => not not our $SERIAL_IDS;
 
@@ -182,6 +182,8 @@ has live_objects => (
         objects_to_ids     => "objects_to_ids",
         id_to_object       => "id_to_object",
         ids_to_objects     => "ids_to_objects",
+        id_in_storage      => "id_in_storage",
+        object_in_storage  => "object_in_storage",
     },
 );
 
@@ -698,7 +700,7 @@ If you're new to L<KiokuDB> check out L<KiokuDB::Tutorial>.
 
 
 
-    # some backends (like DBI) support simple searchs
+    # some backends (like DBI) support simple searches
     $d->search({ name => "foo" });
 
 
@@ -760,7 +762,7 @@ more detail.
 =head2 Collapsing
 
 When an object is stored using L<KiokuDB> it's collapsed into an
-L<KiokDB::Entry|Entry>.
+L<KiokuDB::Entry|Entry>.
 
 An entry is a simplified representation of the object, allowing the data to be
 saved in formats as simple as JSON.
@@ -1151,7 +1153,7 @@ needed.
 
 L<KiokuDB::Collapser>
 
-The collapser prepares objects for storage, by creating L<KiokDB::Entry>
+The collapser prepares objects for storage, by creating L<KiokuDB::Entry>
 objects to pass to the backend.
 
 =item linker
